package Finance::Dogecoin::Utils;
# ABSTRACT: Libraries and Utilities to work with Dogecoin
$Finance::Dogecoin::Utils::VERSION = '1.20240412.1911';
use strict;
use warnings;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Finance::Dogecoin::Utils - Libraries and Utilities to work with Dogecoin

=head1 VERSION

version 1.20240412.1911

=head1 SYNOPSIS

See L<dogeutils>

=head1 COPYRIGHT

Copyright (c) 2022-2024 chromatic

=head1 AUTHOR

chromatic

=head1 AUTHOR

chromatic <chromatic@wgz.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2022-2024 by chromatic.

This is free software, licensed under:

  The MIT (X11) License

=cut
